hardware

package
v0.6.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 29, 2025 License: GPL-3.0 Imports: 12 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Console

type Console struct {
	MC    *cpu.CPU
	Mem   *memory.Memory
	MARIA *maria.Maria
	TIA   *tia.TIA
	RIOT  *riot.RIOT
	// contains filtered or unexported fields
}

func Create

func Create(ctx Context, g *gui.GUI) *Console

func (*Console) Insert

func (con *Console) Insert(c external.CartridgeInsertor) error

func (*Console) LastAreaStatus

func (con *Console) LastAreaStatus() string

LastAreaStatus returns the status of the last memory area to be written to (if the memory area provides the Status() function).

Once this function has been executed, the last memory area information is gone and it will return nothing until the next memory write.

func (*Console) Reset

func (con *Console) Reset(random bool) error

func (*Console) Run

func (con *Console) Run(hook func() error) error

func (*Console) Step

func (con *Console) Step() error

type Context

type Context interface {
	memory.Context
	tia.Context
	maria.Context
	Rand8Bit() uint8
	Rand16Bit() uint16
	UseAudio() bool
}

Directories

Path Synopsis
arm
Package arm imlplements the ARM7TDMI instruction set as defined in the ARM7TDMI Instruction Set Reference:
Package arm imlplements the ARM7TDMI instruction set as defined in the ARM7TDMI Instruction Set Reference:
architecture
Package architecture defines the Map type that is used to specify the differences in cartridge and ARM archtectures.
Package architecture defines the Map type that is used to specify the differences in cartridge and ARM archtectures.
fpu
rng
Package rng contains an implementation of a RNG peripheral found in some ARM CPU packages.
Package rng contains an implementation of a RNG peripheral found in some ARM CPU packages.
timer
Package timer contains implementations of timer peripherals found in the various ARM CPU packages.
Package timer contains implementations of timer peripherals found in the various ARM CPU packages.
cpu
Package cpu emulates the 6507 microprocessor found in the Atari VCS.
Package cpu emulates the 6507 microprocessor found in the Atari VCS.
execution
Package execution tracks the result of instruction execution on the CPU.
Package execution tracks the result of instruction execution on the CPU.
instructions
Package instructions defines the table of instruction for the 6507.
Package instructions defines the table of instruction for the 6507.
klaus2m5
Package klaus2m5 contains the various 6502 functional tests as created/maintained by Klaus Dormann.
Package klaus2m5 contains the various 6502 functional tests as created/maintained by Klaus Dormann.
registers
Package registers implements the three types of registers found in the 6507.
Package registers implements the three types of registers found in the 6507.
registers/test
Package test contains functions useful for testing CPU registers.
Package test contains functions useful for testing CPU registers.
external/elf
Package ace implements the ELF cartridge mapper.
Package ace implements the ELF cartridge mapper.
ram
Package pokey implements the audio generation of the POKEY.
Package pokey implements the audio generation of the POKEY.
tia
audio
Package audio implements the audio generation of the TIA.
Package audio implements the audio generation of the TIA.
audio/mix
Package mix is used to combine two distinct sound sources into either a mono or stereo signal.
Package mix is used to combine two distinct sound sources into either a mono or stereo signal.

Jump to