Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Console ¶
type Console struct {
MC *cpu.CPU
Mem *memory.Memory
MARIA *maria.Maria
TIA *tia.TIA
RIOT *riot.RIOT
// contains filtered or unexported fields
}
func (*Console) LastAreaStatus ¶
LastAreaStatus returns the status of the last memory area to be written to (if the memory area provides the Status() function).
Once this function has been executed, the last memory area information is gone and it will return nothing until the next memory write.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package arm imlplements the ARM7TDMI instruction set as defined in the ARM7TDMI Instruction Set Reference:
|
Package arm imlplements the ARM7TDMI instruction set as defined in the ARM7TDMI Instruction Set Reference: |
|
architecture
Package architecture defines the Map type that is used to specify the differences in cartridge and ARM archtectures.
|
Package architecture defines the Map type that is used to specify the differences in cartridge and ARM archtectures. |
|
rng
Package rng contains an implementation of a RNG peripheral found in some ARM CPU packages.
|
Package rng contains an implementation of a RNG peripheral found in some ARM CPU packages. |
|
timer
Package timer contains implementations of timer peripherals found in the various ARM CPU packages.
|
Package timer contains implementations of timer peripherals found in the various ARM CPU packages. |
|
Package cpu emulates the 6507 microprocessor found in the Atari VCS.
|
Package cpu emulates the 6507 microprocessor found in the Atari VCS. |
|
execution
Package execution tracks the result of instruction execution on the CPU.
|
Package execution tracks the result of instruction execution on the CPU. |
|
instructions
Package instructions defines the table of instruction for the 6507.
|
Package instructions defines the table of instruction for the 6507. |
|
instructions/generator
command
|
|
|
klaus2m5
Package klaus2m5 contains the various 6502 functional tests as created/maintained by Klaus Dormann.
|
Package klaus2m5 contains the various 6502 functional tests as created/maintained by Klaus Dormann. |
|
registers
Package registers implements the three types of registers found in the 6507.
|
Package registers implements the three types of registers found in the 6507. |
|
registers/test
Package test contains functions useful for testing CPU registers.
|
Package test contains functions useful for testing CPU registers. |
|
external/elf
Package ace implements the ELF cartridge mapper.
|
Package ace implements the ELF cartridge mapper. |
|
Package pokey implements the audio generation of the POKEY.
|
Package pokey implements the audio generation of the POKEY. |
|
audio
Package audio implements the audio generation of the TIA.
|
Package audio implements the audio generation of the TIA. |
|
audio/mix
Package mix is used to combine two distinct sound sources into either a mono or stereo signal.
|
Package mix is used to combine two distinct sound sources into either a mono or stereo signal. |
Click to show internal directories.
Click to hide internal directories.